package Number::Phone::JP::Table::Class1;

use strict;
use warnings;

our $VERSION = '0.20160201';

# Table last modified: 2016-02-01
our %TEL_TABLE = (
    # Pref => q<Assoc-Pref-Regex>,
    '01'    => '\d+', # KDDI
    '030'   => '\d+', # ZIP Telecom
    '031'   => '\d+', # アイ・ピー・エス
    '032'   => '\d+', # アイ・ピー・エス
    '033'   => '\d+', # NTTコミュニケーションズ
    '034'   => '\d+', # NTTコミュニケーションズ
    '035'   => '\d+', # NTTコミュニケーションズ
    '036'   => '\d+', # NTT東日本
    '037'   => '\d+', # 楽天コミュニケーションズ
    '038'   => '\d+', # 楽天コミュニケーションズ
    '039'   => '\d+', # NTT西日本
    '041'   => '\d+', # ソフトバンク
    '046'   => '\d+', # ソフトバンク
    '051'   => '\d+', # KDDI
    '052'   => '\d+', # KDDI
    '053'   => '\d+', # KDDI
    '054'   => '\d+', # KDDI
    '055'   => '\d+', # KDDI
    '056'   => '\d+', # KDDI
    '057'   => '\d+', # KDDI
    '060'   => '\d+', # アルテリア・ネットワークス
    '061'   => '\d+', # ソフトバンク
    '062'   => '\d+', # ソフトバンク
    '063'   => '\d+', # ソフトバンク
    '065'   => '\d+', # ソフトバンク
    '066'   => '\d+', # ソフトバンク
    '067'   => '\d+', # りーふねっと
    '070'   => '\d+', # KDDI
    '073'   => '\d+', # 安子の電話
    '074'   => '\d+', # 安子の電話
    '077'   => '\d+', # KDDI
    '081'   => '\d+', # 楽天コミュニケーションズ
    '082'   => '\d+', # 楽天コミュニケーションズ
    '083'   => '\d+', # ソフトバンク
    '084'   => '\d+', # ソフトバンク
    '086'   => '\d+', # 九州通信ネットワーク
    '088'   => '\d+', # ソフトバンク
);

1;
__END__
